@@ -514,7 +514,7 @@ SG.Est <- function(dat, Q, weight=NULL, model, sequential,att.dist, att.prior, s
        posterior.prob = postP, pf = pf, attributepattern = AlphaPattern,
        testfit = list(Deviance=neg2LL,npar = npar,item.npar = free.item.npar,
                       AIC=2 * npar + neg2LL, BIC=neg2LL + npar * log(length(raw2unique)),
-                      CAIC=neg2LL + npar * log(length(raw2unique)+1),
+                      CAIC=neg2LL + npar * (log(length(raw2unique))+1),
                       SABIC=neg2LL + npar * log((length(raw2unique)+2)/24)),
        technicals = list(logposterior.i = estep$logpost[raw2unique, ], loglikelihood.i = estep$loglik[raw2unique, ],
                          free.item.npar = free.item.npar,
